import { useAuthStore } from "@/stores/auth.store";
import { createRouter, createWebHistory } from "vue-router";
import RouteView from "../views/RouteView.vue";

export const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: "/",
      name: "Home",
      redirect: "/user/list",
    },
    {
      path: "/login",
      name: "Login",
      component: () => import("../views/LoginView.vue"),
    },
    {
      path: "/user",
      name: "User",
      component: RouteView,
      children: [
        {
          path: "create",
          name: "Create",
          component: () => import("../views/user/CreateUser.vue"),
        },
        {
          path: "list",
          name: "LIst",
          component: () => import("../views/user/UserList.vue"),
        },
      ],
    },
    {
      path: "/report",
      name: "Report",
      component: RouteView,
      children: [
        {
          path: "rlist",
          name: "RList",
          component: () => import("../views/report/ReportListView.vue"),
        },
        {
          path: "detail/:id",
          name: "ReportDetail",
          component: () => import("../views/report/ReportDetailView.vue"),
        },
      ],
    },
  ],
});

router.beforeResolve(async (to) => {
  const authStore = useAuthStore();

  if (to.name != "Login" && !authStore.isLoginIn()) {
    return { name: "Login" };
  }
});

export function routeToHome() {
  router.push({ name: "Home" });
}

export function routeToLogin() {
  router.push({ name: "Login" });
}
